=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2006-03-04 22:35:19 +0000
+++ bzrlib/commit.py	2006-03-04 23:04:37 +0000
@@ -227,6 +227,7 @@
 
         self.weave_store = self.branch.repository.weave_store
         self.bound_branch = None
+        self.local = local
         self.master_branch = None
         self.rev_id = rev_id
         self.specific_files = specific_files
@@ -240,9 +241,6 @@
             # setup the bound branch variables as needed.
             self._check_bound_branch()
 
-            if not self.bound_branch and local:
-                raise errors.LocalRequiresBoundBranch()
-
             # check for out of date working trees
             # if we are bound, then self.branch is the master branch and this
             # test is thus all we need.
@@ -355,10 +353,12 @@
         done using the remote branch as the target branch.
         Only at the end will the local branch be updated.
         """
-        # TODO: jam 20051230 Consider a special error for the case
-        #       where the local branch is bound, and can't access the
-        #       master branch
-        self.master_branch = self.branch.get_master_branch()
+        if self.local and not self.branch.get_bound_location():
+            raise errors.LocalRequiresBoundBranch()
+
+        if not self.local:
+            self.master_branch = self.branch.get_master_branch()
+
         if not self.master_branch:
             # make this branch the reference branch for out of date checks.
             self.master_branch = self.branch

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2006-03-04 22:35:19 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2006-03-04 23:04:37 +0000
@@ -90,4 +90,3 @@
         self.assertEqualDiff('', out)
         self.assertEqualDiff('bzr: ERROR: Cannot perform local-only commits '
                              'on unbound branches.\n', err)
-        

=== modified file 'bzrlib/tests/workingtree_implementations/test_workingtree.py'
--- bzrlib/tests/workingtree_implementations/test_workingtree.py	2006-03-04 22:35:19 +0000
+++ bzrlib/tests/workingtree_implementations/test_workingtree.py	2006-03-04 23:04:37 +0000
@@ -335,7 +335,42 @@
                           tree.commit,
                           'foo',
                           local=True)
-
+ 
+    def test_local_commit_ignores_master(self):
+        # a --local commit does not require access to the master branch
+        # at all, or even for it to exist.
+        # we test this by setting up a bound branch and then corrupting
+        # the master.
+        master = self.make_branch('master')
+        tree = self.make_branch_and_tree('tree')
+        try:
+            tree.branch.bind(master)
+        except errors.UpgradeRequired:
+            # older format.
+            return
+        master.bzrdir.transport.put('branch-format', StringIO('garbage'))
+        del master
+        # check its corrupted.
+        self.assertRaises(errors.UnknownFormatError,
+                          bzrdir.BzrDir.open,
+                          'master')
+        tree.commit('foo', rev_id='foo', local=True)
+ 
+    def test_local_commit_does_not_push_to_master(self):
+        # a --local commit does not require access to the master branch
+        # at all, or even for it to exist.
+        # we test that even when its available it does not push to it.
+        master = self.make_branch('master')
+        tree = self.make_branch_and_tree('tree')
+        try:
+            tree.branch.bind(master)
+        except errors.UpgradeRequired:
+            # older format.
+            return
+        tree.commit('foo', rev_id='foo', local=True)
+        self.failIf(master.repository.has_revision('foo'))
+        self.assertEqual(None, master.last_revision())
+        
     def test_update_sets_last_revision(self):
         # working tree formats from the meta-dir format and newer support
         # setting the last revision on a tree independently of that on the 

